summaryrefslogtreecommitdiffstats
path: root/kimagemapeditor/kimagemapeditor.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:36 -0600
commit1fffbdafa12271a1a635caf46777fb8acfb6f31b (patch)
tree707785bd058e254fd865ca30ed35f37f206aebbc /kimagemapeditor/kimagemapeditor.cpp
parent2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076 (diff)
downloadtdewebdev-1fffbdafa12271a1a635caf46777fb8acfb6f31b.tar.gz
tdewebdev-1fffbdafa12271a1a635caf46777fb8acfb6f31b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076.
Diffstat (limited to 'kimagemapeditor/kimagemapeditor.cpp')
-rw-r--r--kimagemapeditor/kimagemapeditor.cpp72
1 files changed, 36 insertions, 36 deletions
diff --git a/kimagemapeditor/kimagemapeditor.cpp b/kimagemapeditor/kimagemapeditor.cpp
index 2c59cf3d..6dbb1a32 100644
--- a/kimagemapeditor/kimagemapeditor.cpp
+++ b/kimagemapeditor/kimagemapeditor.cpp
@@ -19,7 +19,7 @@
#include <assert.h>
// QT
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlistview.h>
#include <tqpushbutton.h>
#include <tqvbox.h>
@@ -28,7 +28,7 @@
#include <tqsplitter.h>
#include <tqfileinfo.h>
#include <tqmultilineedit.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqpopupmenu.h>
#include <tqdict.h>
#include <tqwhatsthis.h>
@@ -396,7 +396,7 @@ void KImageMapEditor::slotConfigChanged()
}
updateAllAreas();
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
}
void KImageMapEditor::openLastURL(KConfig* config) {
@@ -425,7 +425,7 @@ void KImageMapEditor::saveLastURL(KConfig* config) {
// kdDebug() << "writing entry lastopenurl : " << url().path() << endl;
// kdDebug() << "writing entry lastactivemap : " << mapName() << endl;
// kdDebug() << "writing entry lastactiveimage : " << _imageUrl.path() << endl;
- //KMessageBox::information(0L, TQString("Group: %1 Saving ... %2").arg(config->group()).arg(url().path()));
+ //KMessageBox::information(0L, TQString("Group: %1 Saving ... %2").tqarg(config->group()).tqarg(url().path()));
}
void KImageMapEditor::setupActions()
@@ -736,7 +736,7 @@ void KImageMapEditor::showPopupMenu(const TQPoint & pos, const TQString & name)
TQPopupMenu* pop = static_cast<TQPopupMenu *>(factory()->container(name, this));
if (!pop) {
- kdWarning() << TQString("KImageMapEditorPart: Missing XML definition for %1\n").arg(name) << endl;
+ kdWarning() << TQString("KImageMapEditorPart: Missing XML definition for %1\n").tqarg(name) << endl;
return;
}
@@ -794,8 +794,8 @@ void KImageMapEditor::updateStatusBar()
void KImageMapEditor::slotChangeStatusCoords(int x,int y)
{
-// statusBar()->changeItem(TQString(" Cursor : x: %1 ,y: %2 ").arg(x).arg(y),STATUS_CURSOR);
- cursorStatusText = i18n(" Cursor: x: %1, y: %2 ").arg(x).arg(y);
+// statusBar()->changeItem(TQString(" Cursor : x: %1 ,y: %2 ").tqarg(x).tqarg(y),STATUS_CURSOR);
+ cursorStatusText = i18n(" Cursor: x: %1, y: %2 ").tqarg(x).tqarg(y);
updateStatusBar();
}
@@ -803,7 +803,7 @@ void KImageMapEditor::slotUpdateSelectionCoords() {
if (selected()->count()>0) {
TQRect r=selected()->rect();
// statusBar()->changeItem(
- selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").arg(r.left()).arg(r.top()).arg(r.width()).arg(r.height());
+ selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").tqarg(r.left()).tqarg(r.top()).tqarg(r.width()).tqarg(r.height());
// ,STATUS_SELECTION);
kapp->processEvents();
@@ -816,7 +816,7 @@ void KImageMapEditor::slotUpdateSelectionCoords() {
void KImageMapEditor::slotUpdateSelectionCoords( const TQRect & r )
{
- selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").arg(r.left()).arg(r.top()).arg(r.width()).arg(r.height());
+ selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ").tqarg(r.left()).tqarg(r.top()).tqarg(r.width()).tqarg(r.height());
updateStatusBar();
kapp->processEvents();
}
@@ -990,7 +990,7 @@ void KImageMapEditor::deleteArea( Area * area )
{
if (!area) return;
// only for repaint reasons
TQRect redrawRect = area->selectionRect();
// Perhaps we've got a selection of areas
@@ -1055,7 +1055,7 @@ void KImageMapEditor::deleteAllAreas()
a=areas->first(); // because the current is deleted
}
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
}
@@ -1065,7 +1065,7 @@ void KImageMapEditor::updateAllAreas()
for (Area* a=areas->first();a!=0L;a=areas->next()) {
a->listViewItem()->setPixmap(1,makeListViewPix(*a));
}
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
}
void KImageMapEditor::updateSelection() const {
@@ -1407,10 +1407,10 @@ void KImageMapEditor::setPicture(const KURL & url) {
imageUsemapAction->setEnabled(true);
}
else
- kdError() << TQString("The image %1 could not be opened.").arg(url.path()) << endl;
+ kdError() << TQString("The image %1 could not be opened.").tqarg(url.path()) << endl;
}
else
- kdError() << TQString("The image %1 does not exist.").arg(url.path()) << endl;
+ kdError() << TQString("The image %1 does not exist.").tqarg(url.path()) << endl;
}
void KImageMapEditor::setPicture(const TQImage & pix) {
@@ -1519,7 +1519,7 @@ void KImageMapEditor::mapEditName()
if (ok) {
if (input != _mapName) {
if (mapsListView->nameAlreadyExists(input))
- KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.").arg(input));
+ KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.").tqarg(input));
else {
setMapName(input);
}
@@ -1622,12 +1622,12 @@ void KImageMapEditor::fileSaveAs() {
if ( fileInfo.exists() )
{
if (KMessageBox::warningContinueCancel(widget(),
- i18n("<qt>The file <em>%1</em> already exists.<br>Do you want to overwrite it?</qt>").arg(fileInfo.fileName()),
+ i18n("<qt>The file <em>%1</em> already exists.<br>Do you want to overwrite it?</qt>").tqarg(fileInfo.fileName()),
i18n("Overwrite File?"), i18n("Overwrite"))==KMessageBox::Cancel)
return;
if(!fileInfo.isWritable()) {
- KMessageBox::sorry(widget(), i18n("<qt>You do not have write permission for the file <em>%1</em>.</qt>").arg(fileInfo.fileName()));
+ KMessageBox::sorry(widget(), i18n("<qt>You do not have write permission for the file <em>%1</em>.</qt>").tqarg(fileInfo.fileName()));
return;
}
}
@@ -1646,14 +1646,14 @@ bool KImageMapEditor::openFile()
if ( !fileInfo.exists() )
{
KMessageBox::information(widget(),
- i18n("<qt>The file <b>%1</b> does not exist.</qt>").arg(fileInfo.fileName()),
+ i18n("<qt>The file <b>%1</b> does not exist.</qt>").tqarg(fileInfo.fileName()),
i18n("File Does Not Exist"));
return false;
}
openHTMLFile(url());
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
recentFilesAction->addURL(url());
setModified(false);
backupFileCreated = false;
@@ -2107,16 +2107,16 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
map->clear();
for (Area* a=areas->first();a!=0L;a=areas->next()) {
TQDict<TQString> *dict = new TQDict<TQString>(17,false);
- TQString *shapeStr = 0L;
+ TQString *tqshapeStr = 0L;
switch (a->type()) {
- case Area::Rectangle : shapeStr = new TQString("rect");break;
- case Area::Circle : shapeStr = new TQString("circle");break;
- case Area::Polygon : shapeStr = new TQString("poly");break;
+ case Area::Rectangle : tqshapeStr = new TQString("rect");break;
+ case Area::Circle : tqshapeStr = new TQString("circle");break;
+ case Area::Polygon : tqshapeStr = new TQString("poly");break;
default : continue;
}
- dict->insert("shape",shapeStr);
+ dict->insert("tqshape",tqshapeStr);
for (AttributeIterator it = a->firstAttribute();it!=a->lastAttribute();++it) {
dict->insert(it.key(),new TQString(it.data()));
@@ -2130,7 +2130,7 @@ void KImageMapEditor::saveAreasToMapTag(MapTag* map) {
if (defaultArea && defaultArea->finished()) {
TQDict<TQString> *dict = new TQDict<TQString>(17,false);
- dict->insert("shape",new TQString("default"));
+ dict->insert("tqshape",new TQString("default"));
for (AttributeIterator it = defaultArea->firstAttribute();it!=defaultArea->lastAttribute();++it) {
dict->insert(it.key(),new TQString(it.data()));
@@ -2159,16 +2159,16 @@ void KImageMapEditor::setMap(HtmlMapElement* mapElement) {
_mapName = map->name;
for (AreaTag *tag=map->first();tag!=0L;tag=map->next())
{
- TQString shape="rect";
- if (tag->find("shape"))
- shape=*tag->find("shape");
+ TQString tqshape="rect";
+ if (tag->find("tqshape"))
+ tqshape=*tag->find("tqshape");
Area::ShapeType type=Area::Rectangle;
- if (shape=="circle")
+ if (tqshape=="circle")
type=Area::Circle;
- else if (shape=="poly")
+ else if (tqshape=="poly")
type=Area::Polygon;
- else if (shape=="default")
+ else if (tqshape=="default")
type=Area::Default;
Area* a=AreaCreator::create(type);
@@ -2267,7 +2267,7 @@ void KImageMapEditor::saveImageMap(const KURL & url)
if (!TQFileInfo(url.directory()).isWritable()) {
KMessageBox::error(widget(),
- i18n("<qt>The file <i>%1</i> could not be saved, because you do not have the required write permissions.</qt>").arg(url.path()));
+ i18n("<qt>The file <i>%1</i> could not be saved, because you do not have the required write permissions.</qt>").tqarg(url.path()));
return;
}
@@ -2556,7 +2556,7 @@ void KImageMapEditor::slotHightlightAreas()
// highlightAreasAction->setChecked(b);
Area::highlightArea = b;
updateAllAreas();
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
}
void KImageMapEditor::slotShowAltTag()
@@ -2564,7 +2564,7 @@ void KImageMapEditor::slotShowAltTag()
bool b = showAltAction->isChecked();
// showAltAction->setChecked(b);
Area::showAlt = b;
- drawZone->viewport()->repaint();
+ drawZone->viewport()->tqrepaint();
}
void KImageMapEditor::mapNew()
@@ -2583,7 +2583,7 @@ void KImageMapEditor::mapDelete()
int result = KMessageBox::warningContinueCancel(widget(),
i18n("<qt>Are you sure you want to delete the map <i>%1</i>?"
- " <br><b>There is no way to undo this.</b></qt>").arg(selectedMap),
+ " <br><b>There is no way to undo this.</b></qt>").tqarg(selectedMap),
i18n("Delete Map?"),KGuiItem(i18n("&Delete"),"editdelete"));
if (result == KMessageBox::No)
@@ -2631,7 +2631,7 @@ bool KImageMapEditor::queryClose() {
return true;
switch ( KMessageBox::warningYesNoCancel( widget(),
- i18n("<qt>The file <i>%1</i> has been modified.<br>Do you want to save it?</qt>").arg(url().fileName()), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) ) {
+ i18n("<qt>The file <i>%1</i> has been modified.<br>Do you want to save it?</qt>").tqarg(url().fileName()), TQString(), KStdGuiItem::save(), KStdGuiItem::discard()) ) {
case KMessageBox::Yes :
saveFile();
return true;
@@ -990,7 +990,7 @@ void KImageMapEditor::deleteArea( Area * area )
{
if (!area) return;
- // only for repaint reasons
+ // only for tqrepaint reasons
TQRect redrawRect = area->selectionRect();
// Perhaps we've got a selection of areas